/**
 * Copyright (c) 2011-2013 by Andrew Mustun. All rights reserved.
 *
 * Copyright (c) 2014 by Robert S. All rights reserved.
 * 
 * This file is part of the QCAD project.
 *
 * QCAD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * QCAD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with QCAD.
 */

include("../NewFile/NewFile.js");

if (new QFileInfo("scripts/File/AutoSave/AutoSave.js")) {
    include("scripts/File/AutoSave/AutoSave.js");
}

/**
 * \class RunScript
 * \brief Handles all user interaction to load and run scripts.
 * \ingroup ecma_file
 */
function RunScript(guiAction) {
    NewFile.call(this, guiAction);
}

RunScript.prototype = new NewFile();

RunScript.prototype.beginEvent = function() {
    File.prototype.beginEvent.call(this);

    var filters = RFileImporterRegistry.getFilterStrings();
    if (filters.length===0) {
        var dlg = new QMessageBox(QMessageBox.Warning,
                qsTr("No import filters"),
                "",
                QMessageBox.OK);
        dlg.text = qsTr("No import filters have been found. Aborting...");
        dlg.exec();
        return;
    }

    if (!isNull(this.guiAction)) {
        var fileName = this.guiAction.data();
        if (!isNull(fileName)) {
            NewFile.createMdiChild(fileName);
            return;
        }
    }

    var lastOpenFileDir = RSettings.getStringValue(
            "OpenFile/Path",
            RSettings.getDocumentsLocation());

    var fileDialog = new QFileDialog(appWin, qsTr("Open Script File"), lastOpenFileDir, "");
    var allFilter = filters[0];
    filters = new Array(qsTr("All Files") + " (*)", qsTr("Script Files") + " (*.js)");
    fileDialog.setNameFilters(filters);
    fileDialog.selectNameFilter(allFilter);
    fileDialog.setOption(QFileDialog.DontUseNativeDialog, false);
    fileDialog.fileMode = QFileDialog.ExistingFiles;
    fileDialog.setLabelText(QFileDialog.FileType, qsTr("Format:"));
    if (!fileDialog.exec()) {
        fileDialog.destroy();
        return;
    }
    RSettings.setValue("OpenFile/Path", fileDialog.directory().absolutePath());

    var fileNames = fileDialog.selectedFiles();
    fileDialog.destroy();
    for ( var i = 0; i < fileNames.length; ++i) {
        var action = RGuiAction.getByScriptFile(fileNames[i]);
        if (!isNull(action)) {
            action.slotTrigger();
        } else {
            var contents = RFileCache.getContents(fileNames[i], true);
            //eval(contents);
            // avoid using eval()
            var func = new Function(contents);
            func();
        }
    }
};

